pub struct XRHeader {
pub block_type: BlockType,
pub type_specific: TypeSpecificField,
pub block_length: u16,
}Expand description
XRHeader defines the common fields that must appear at the start of each report block. In typical cases, users of ExtendedReports shouldn’t need to access this. For locally-constructed report blocks, these values will not be accurate until the corresponding packet is marshaled.
Fields
block_type: BlockTypeWhich kind of report block follows.
type_specific: TypeSpecificFieldBits whose meaning depends on the block type.
block_length: u16The block’s length in 32-bit words, excluding this header.