pub struct UnknownReportBlock {
pub bytes: Bytes,
}Expand description
UnknownReportBlock is used to store bytes for any report block that has an unknown Report Block Type.
Fields
bytes: BytesThe block’s bytes, left unparsed.
Implementations