Module goodbye
rtc_
rtcp
0.20.0
Module goodbye
Module Items
Structs
In crate rtc_
rtcp
rtc_rtcp
Module
goodbye
The BYE packet, by which a source announces it is leaving.
Structs

Goodbye
The Goodbye packet indicates that one or more sources are no longer active.