Module raw_packet

Module raw_packet 

An unparsed packet, used for types this crate does not model.

Structs

RawPacket
RawPacket represents an unparsed RTCP packet. It’s returned by Unmarshal when a packet with an unknown type is encountered.