pub struct SenderReport {
pub ssrc: u32,
pub ntp_time: u64,
pub rtp_time: u32,
pub packet_count: u32,
pub octet_count: u32,
pub reports: Vec<ReceptionReport>,
pub profile_extensions: Bytes,
}Expand description
A SenderReport (SR) packet provides reception quality feedback for an RTP stream
Fields
ssrc: u32The synchronization source identifier for the originator of this SR packet.
ntp_time: u64The wallclock time when this report was sent so that it may be used in combination with timestamps returned in reception reports from other receivers to measure round-trip propagation to those receivers.
rtp_time: u32Corresponds to the same time as the NTP timestamp (above), but in the same units and with the same random offset as the RTP timestamps in data packets. This correspondence may be used for intra- and inter-media synchronization for sources whose NTP timestamps are synchronized, and may be used by media-independent receivers to estimate the nominal RTP clock frequency.
packet_count: u32The total number of RTP data packets transmitted by the sender since starting transmission up until the time this SR packet was generated.
octet_count: u32The total number of payload octets (i.e., not including header or padding) transmitted in RTP data packets by the sender since starting transmission up until the time this SR packet was generated.
reports: Vec<ReceptionReport>Zero or more reception report blocks depending on the number of other sources heard by this sender since the last report. Each reception report block conveys statistics on the reception of RTP packets from a single synchronization source.
profile_extensions: BytesProfileExtensions contains additional, payload-specific information that needs to be reported regularly about the sender.