pub struct RapidResynchronizationRequest {
pub sender_ssrc: u32,
pub media_ssrc: u32,
}Expand description
The RapidResynchronizationRequest packet informs the encoder about the loss of an undefined amount of coded video data belonging to one or more pictures
Fields
sender_ssrc: u32SSRC of sender
media_ssrc: u32SSRC of the media source